import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as DelegationsAPI from 'cloudflare/resources/addressing/prefixes/delegations';
export declare class Delegations extends APIResource {
    /**
     * Create a new account delegation for a given IP prefix.
     */
    create(prefixId: string, params: DelegationCreateParams, options?: Core.RequestOptions): Core.APIPromise<AddressingIpamDelegations>;
    /**
     * List all delegations for a given account IP prefix.
     */
    list(prefixId: string, params: DelegationListParams, options?: Core.RequestOptions): Core.APIPromise<DelegationListResponse | null>;
    /**
     * Delete an account delegation for a given IP prefix.
     */
    delete(prefixId: string, delegationId: string, params: DelegationDeleteParams, options?: Core.RequestOptions): Core.APIPromise<DelegationDeleteResponse>;
}
export interface AddressingIpamDelegations {
    /**
     * Delegation identifier tag.
     */
    id?: string;
    /**
     * IP Prefix in Classless Inter-Domain Routing format.
     */
    cidr?: string;
    created_at?: string;
    /**
     * Account identifier for the account to which prefix is being delegated.
     */
    delegated_account_id?: string;
    modified_at?: string;
    /**
     * Identifier
     */
    parent_prefix_id?: string;
}
export type DelegationListResponse = Array<AddressingIpamDelegations>;
export interface DelegationDeleteResponse {
    /**
     * Delegation identifier tag.
     */
    id?: string;
}
export interface DelegationCreateParams {
    /**
     * Path param: Identifier
     */
    account_id: string;
    /**
     * Body param: IP Prefix in Classless Inter-Domain Routing format.
     */
    cidr: string;
    /**
     * Body param: Account identifier for the account to which prefix is being
     * delegated.
     */
    delegated_account_id: string;
}
export interface DelegationListParams {
    /**
     * Identifier
     */
    account_id: string;
}
export interface DelegationDeleteParams {
    /**
     * Identifier
     */
    account_id: string;
}
export declare namespace Delegations {
    export import AddressingIpamDelegations = DelegationsAPI.AddressingIpamDelegations;
    export import DelegationListResponse = DelegationsAPI.DelegationListResponse;
    export import DelegationDeleteResponse = DelegationsAPI.DelegationDeleteResponse;
    export import DelegationCreateParams = DelegationsAPI.DelegationCreateParams;
    export import DelegationListParams = DelegationsAPI.DelegationListParams;
    export import DelegationDeleteParams = DelegationsAPI.DelegationDeleteParams;
}
//# sourceMappingURL=delegations.d.ts.map