import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as PriorityAPI from 'cloudflare/resources/cloudforce-one/requests/priority';
import * as RequestsAPI from 'cloudflare/resources/cloudforce-one/requests/requests';
export declare class Priority extends APIResource {
    /**
     * Create a New Priority Requirement
     */
    create(accountIdentifier: string, body: PriorityCreateParams, options?: Core.RequestOptions): Core.APIPromise<CloudforceOnePriorityItem>;
    /**
     * Update a Priority Intelligence Requirement
     */
    update(accountIdentifier: string, priorityIdentifer: string, body: PriorityUpdateParams, options?: Core.RequestOptions): Core.APIPromise<RequestsAPI.CloudforceOneRequestItem>;
    /**
     * Delete a Priority Intelligence Report
     */
    delete(accountIdentifier: string, priorityIdentifer: string, options?: Core.RequestOptions): Core.APIPromise<PriorityDeleteResponse>;
    /**
     * Get a Priority Intelligence Requirement
     */
    get(accountIdentifier: string, priorityIdentifer: string, options?: Core.RequestOptions): Core.APIPromise<RequestsAPI.CloudforceOneRequestItem>;
    /**
     * Get Priority Intelligence Requirement Quota
     */
    quota(accountIdentifier: string, options?: Core.RequestOptions): Core.APIPromise<RequestsAPI.CloudforceOneQuota>;
}
export interface CloudforceOnePriorityItem {
    /**
     * UUID
     */
    id: string;
    /**
     * Priority creation time
     */
    created: string;
    /**
     * List of labels
     */
    labels: Array<string>;
    /**
     * Priority
     */
    priority: number;
    /**
     * Requirement
     */
    requirement: string;
    /**
     * The CISA defined Traffic Light Protocol (TLP)
     */
    tlp: 'clear' | 'amber' | 'amber-strict' | 'green' | 'red';
    /**
     * Priority last updated time
     */
    updated: string;
}
export type PriorityDeleteResponse = unknown | Array<unknown> | string;
export interface PriorityCreateParams {
    /**
     * List of labels
     */
    labels: Array<string>;
    /**
     * Priority
     */
    priority: number;
    /**
     * Requirement
     */
    requirement: string;
    /**
     * The CISA defined Traffic Light Protocol (TLP)
     */
    tlp: 'clear' | 'amber' | 'amber-strict' | 'green' | 'red';
}
export interface PriorityUpdateParams {
    /**
     * List of labels
     */
    labels: Array<string>;
    /**
     * Priority
     */
    priority: number;
    /**
     * Requirement
     */
    requirement: string;
    /**
     * The CISA defined Traffic Light Protocol (TLP)
     */
    tlp: 'clear' | 'amber' | 'amber-strict' | 'green' | 'red';
}
export declare namespace Priority {
    export import CloudforceOnePriorityItem = PriorityAPI.CloudforceOnePriorityItem;
    export import PriorityDeleteResponse = PriorityAPI.PriorityDeleteResponse;
    export import PriorityCreateParams = PriorityAPI.PriorityCreateParams;
    export import PriorityUpdateParams = PriorityAPI.PriorityUpdateParams;
}
//# sourceMappingURL=priority.d.ts.map