import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as HealthchecksAPI from 'cloudflare/resources/healthchecks/healthchecks';
import * as PreviewsAPI from 'cloudflare/resources/healthchecks/previews';
export declare class Healthchecks extends APIResource {
    previews: PreviewsAPI.Previews;
    /**
     * Create a new health check.
     */
    create(zoneIdentifier: string, body: HealthcheckCreateParams, options?: Core.RequestOptions): Core.APIPromise<HealthchecksHealthchecks>;
    /**
     * Update a configured health check.
     */
    update(zoneIdentifier: string, identifier: string, body: HealthcheckUpdateParams, options?: Core.RequestOptions): Core.APIPromise<HealthchecksHealthchecks>;
    /**
     * List configured health checks.
     */
    list(zoneIdentifier: string, options?: Core.RequestOptions): Core.APIPromise<HealthcheckListResponse | null>;
    /**
     * Delete a health check.
     */
    delete(zoneIdentifier: string, identifier: string, options?: Core.RequestOptions): Core.APIPromise<HealthcheckDeleteResponse>;
    /**
     * Patch a configured health check.
     */
    edit(zoneIdentifier: string, identifier: string, body: HealthcheckEditParams, options?: Core.RequestOptions): Core.APIPromise<HealthchecksHealthchecks>;
    /**
     * Fetch a single configured health check.
     */
    get(zoneIdentifier: string, identifier: string, options?: Core.RequestOptions): Core.APIPromise<HealthchecksHealthchecks>;
}
export interface HealthchecksHealthchecks {
    /**
     * Identifier
     */
    id?: string;
    /**
     * The hostname or IP address of the origin server to run health checks on.
     */
    address?: string;
    /**
     * A list of regions from which to run health checks. Null means Cloudflare will
     * pick a default region.
     */
    check_regions?: Array<'WNAM' | 'ENAM' | 'WEU' | 'EEU' | 'NSAM' | 'SSAM' | 'OC' | 'ME' | 'NAF' | 'SAF' | 'IN' | 'SEAS' | 'NEAS' | 'ALL_REGIONS'> | null;
    /**
     * The number of consecutive fails required from a health check before changing the
     * health to unhealthy.
     */
    consecutive_fails?: number;
    /**
     * The number of consecutive successes required from a health check before changing
     * the health to healthy.
     */
    consecutive_successes?: number;
    created_on?: string;
    /**
     * A human-readable description of the health check.
     */
    description?: string;
    /**
     * The current failure reason if status is unhealthy.
     */
    failure_reason?: string;
    /**
     * Parameters specific to an HTTP or HTTPS health check.
     */
    http_config?: HealthchecksHealthchecks.HTTPConfig | null;
    /**
     * The interval between each health check. Shorter intervals may give quicker
     * notifications if the origin status changes, but will increase load on the origin
     * as we check from multiple locations.
     */
    interval?: number;
    modified_on?: string;
    /**
     * A short name to identify the health check. Only alphanumeric characters, hyphens
     * and underscores are allowed.
     */
    name?: string;
    /**
     * The number of retries to attempt in case of a timeout before marking the origin
     * as unhealthy. Retries are attempted immediately.
     */
    retries?: number;
    /**
     * The current status of the origin server according to the health check.
     */
    status?: 'unknown' | 'healthy' | 'unhealthy' | 'suspended';
    /**
     * If suspended, no health checks are sent to the origin.
     */
    suspended?: boolean;
    /**
     * Parameters specific to TCP health check.
     */
    tcp_config?: HealthchecksHealthchecks.TcpConfig | null;
    /**
     * The timeout (in seconds) before marking the health check as failed.
     */
    timeout?: number;
    /**
     * The protocol to use for the health check. Currently supported protocols are
     * 'HTTP', 'HTTPS' and 'TCP'.
     */
    type?: string;
}
export declare namespace HealthchecksHealthchecks {
    /**
     * Parameters specific to an HTTP or HTTPS health check.
     */
    interface HTTPConfig {
        /**
         * Do not validate the certificate when the health check uses HTTPS.
         */
        allow_insecure?: boolean;
        /**
         * A case-insensitive sub-string to look for in the response body. If this string
         * is not found, the origin will be marked as unhealthy.
         */
        expected_body?: string;
        /**
         * The expected HTTP response codes (e.g. "200") or code ranges (e.g. "2xx" for all
         * codes starting with 2) of the health check.
         */
        expected_codes?: Array<string> | null;
        /**
         * Follow redirects if the origin returns a 3xx status code.
         */
        follow_redirects?: boolean;
        /**
         * The HTTP request headers to send in the health check. It is recommended you set
         * a Host header by default. The User-Agent header cannot be overridden.
         */
        header?: unknown | null;
        /**
         * The HTTP method to use for the health check.
         */
        method?: 'GET' | 'HEAD';
        /**
         * The endpoint path to health check against.
         */
        path?: string;
        /**
         * Port number to connect to for the health check. Defaults to 80 if type is HTTP
         * or 443 if type is HTTPS.
         */
        port?: number;
    }
    /**
     * Parameters specific to TCP health check.
     */
    interface TcpConfig {
        /**
         * The TCP connection method to use for the health check.
         */
        method?: 'connection_established';
        /**
         * Port number to connect to for the health check. Defaults to 80.
         */
        port?: number;
    }
}
export type HealthcheckListResponse = Array<HealthchecksHealthchecks>;
export interface HealthcheckDeleteResponse {
    /**
     * Identifier
     */
    id?: string;
}
export interface HealthcheckCreateParams {
    /**
     * The hostname or IP address of the origin server to run health checks on.
     */
    address: string;
    /**
     * A short name to identify the health check. Only alphanumeric characters, hyphens
     * and underscores are allowed.
     */
    name: string;
    /**
     * A list of regions from which to run health checks. Null means Cloudflare will
     * pick a default region.
     */
    check_regions?: Array<'WNAM' | 'ENAM' | 'WEU' | 'EEU' | 'NSAM' | 'SSAM' | 'OC' | 'ME' | 'NAF' | 'SAF' | 'IN' | 'SEAS' | 'NEAS' | 'ALL_REGIONS'> | null;
    /**
     * The number of consecutive fails required from a health check before changing the
     * health to unhealthy.
     */
    consecutive_fails?: number;
    /**
     * The number of consecutive successes required from a health check before changing
     * the health to healthy.
     */
    consecutive_successes?: number;
    /**
     * A human-readable description of the health check.
     */
    description?: string;
    /**
     * Parameters specific to an HTTP or HTTPS health check.
     */
    http_config?: HealthcheckCreateParams.HTTPConfig | null;
    /**
     * The interval between each health check. Shorter intervals may give quicker
     * notifications if the origin status changes, but will increase load on the origin
     * as we check from multiple locations.
     */
    interval?: number;
    /**
     * The number of retries to attempt in case of a timeout before marking the origin
     * as unhealthy. Retries are attempted immediately.
     */
    retries?: number;
    /**
     * If suspended, no health checks are sent to the origin.
     */
    suspended?: boolean;
    /**
     * Parameters specific to TCP health check.
     */
    tcp_config?: HealthcheckCreateParams.TcpConfig | null;
    /**
     * The timeout (in seconds) before marking the health check as failed.
     */
    timeout?: number;
    /**
     * The protocol to use for the health check. Currently supported protocols are
     * 'HTTP', 'HTTPS' and 'TCP'.
     */
    type?: string;
}
export declare namespace HealthcheckCreateParams {
    /**
     * Parameters specific to an HTTP or HTTPS health check.
     */
    interface HTTPConfig {
        /**
         * Do not validate the certificate when the health check uses HTTPS.
         */
        allow_insecure?: boolean;
        /**
         * A case-insensitive sub-string to look for in the response body. If this string
         * is not found, the origin will be marked as unhealthy.
         */
        expected_body?: string;
        /**
         * The expected HTTP response codes (e.g. "200") or code ranges (e.g. "2xx" for all
         * codes starting with 2) of the health check.
         */
        expected_codes?: Array<string> | null;
        /**
         * Follow redirects if the origin returns a 3xx status code.
         */
        follow_redirects?: boolean;
        /**
         * The HTTP request headers to send in the health check. It is recommended you set
         * a Host header by default. The User-Agent header cannot be overridden.
         */
        header?: unknown | null;
        /**
         * The HTTP method to use for the health check.
         */
        method?: 'GET' | 'HEAD';
        /**
         * The endpoint path to health check against.
         */
        path?: string;
        /**
         * Port number to connect to for the health check. Defaults to 80 if type is HTTP
         * or 443 if type is HTTPS.
         */
        port?: number;
    }
    /**
     * Parameters specific to TCP health check.
     */
    interface TcpConfig {
        /**
         * The TCP connection method to use for the health check.
         */
        method?: 'connection_established';
        /**
         * Port number to connect to for the health check. Defaults to 80.
         */
        port?: number;
    }
}
export interface HealthcheckUpdateParams {
    /**
     * The hostname or IP address of the origin server to run health checks on.
     */
    address: string;
    /**
     * A short name to identify the health check. Only alphanumeric characters, hyphens
     * and underscores are allowed.
     */
    name: string;
    /**
     * A list of regions from which to run health checks. Null means Cloudflare will
     * pick a default region.
     */
    check_regions?: Array<'WNAM' | 'ENAM' | 'WEU' | 'EEU' | 'NSAM' | 'SSAM' | 'OC' | 'ME' | 'NAF' | 'SAF' | 'IN' | 'SEAS' | 'NEAS' | 'ALL_REGIONS'> | null;
    /**
     * The number of consecutive fails required from a health check before changing the
     * health to unhealthy.
     */
    consecutive_fails?: number;
    /**
     * The number of consecutive successes required from a health check before changing
     * the health to healthy.
     */
    consecutive_successes?: number;
    /**
     * A human-readable description of the health check.
     */
    description?: string;
    /**
     * Parameters specific to an HTTP or HTTPS health check.
     */
    http_config?: HealthcheckUpdateParams.HTTPConfig | null;
    /**
     * The interval between each health check. Shorter intervals may give quicker
     * notifications if the origin status changes, but will increase load on the origin
     * as we check from multiple locations.
     */
    interval?: number;
    /**
     * The number of retries to attempt in case of a timeout before marking the origin
     * as unhealthy. Retries are attempted immediately.
     */
    retries?: number;
    /**
     * If suspended, no health checks are sent to the origin.
     */
    suspended?: boolean;
    /**
     * Parameters specific to TCP health check.
     */
    tcp_config?: HealthcheckUpdateParams.TcpConfig | null;
    /**
     * The timeout (in seconds) before marking the health check as failed.
     */
    timeout?: number;
    /**
     * The protocol to use for the health check. Currently supported protocols are
     * 'HTTP', 'HTTPS' and 'TCP'.
     */
    type?: string;
}
export declare namespace HealthcheckUpdateParams {
    /**
     * Parameters specific to an HTTP or HTTPS health check.
     */
    interface HTTPConfig {
        /**
         * Do not validate the certificate when the health check uses HTTPS.
         */
        allow_insecure?: boolean;
        /**
         * A case-insensitive sub-string to look for in the response body. If this string
         * is not found, the origin will be marked as unhealthy.
         */
        expected_body?: string;
        /**
         * The expected HTTP response codes (e.g. "200") or code ranges (e.g. "2xx" for all
         * codes starting with 2) of the health check.
         */
        expected_codes?: Array<string> | null;
        /**
         * Follow redirects if the origin returns a 3xx status code.
         */
        follow_redirects?: boolean;
        /**
         * The HTTP request headers to send in the health check. It is recommended you set
         * a Host header by default. The User-Agent header cannot be overridden.
         */
        header?: unknown | null;
        /**
         * The HTTP method to use for the health check.
         */
        method?: 'GET' | 'HEAD';
        /**
         * The endpoint path to health check against.
         */
        path?: string;
        /**
         * Port number to connect to for the health check. Defaults to 80 if type is HTTP
         * or 443 if type is HTTPS.
         */
        port?: number;
    }
    /**
     * Parameters specific to TCP health check.
     */
    interface TcpConfig {
        /**
         * The TCP connection method to use for the health check.
         */
        method?: 'connection_established';
        /**
         * Port number to connect to for the health check. Defaults to 80.
         */
        port?: number;
    }
}
export interface HealthcheckEditParams {
    /**
     * The hostname or IP address of the origin server to run health checks on.
     */
    address: string;
    /**
     * A short name to identify the health check. Only alphanumeric characters, hyphens
     * and underscores are allowed.
     */
    name: string;
    /**
     * A list of regions from which to run health checks. Null means Cloudflare will
     * pick a default region.
     */
    check_regions?: Array<'WNAM' | 'ENAM' | 'WEU' | 'EEU' | 'NSAM' | 'SSAM' | 'OC' | 'ME' | 'NAF' | 'SAF' | 'IN' | 'SEAS' | 'NEAS' | 'ALL_REGIONS'> | null;
    /**
     * The number of consecutive fails required from a health check before changing the
     * health to unhealthy.
     */
    consecutive_fails?: number;
    /**
     * The number of consecutive successes required from a health check before changing
     * the health to healthy.
     */
    consecutive_successes?: number;
    /**
     * A human-readable description of the health check.
     */
    description?: string;
    /**
     * Parameters specific to an HTTP or HTTPS health check.
     */
    http_config?: HealthcheckEditParams.HTTPConfig | null;
    /**
     * The interval between each health check. Shorter intervals may give quicker
     * notifications if the origin status changes, but will increase load on the origin
     * as we check from multiple locations.
     */
    interval?: number;
    /**
     * The number of retries to attempt in case of a timeout before marking the origin
     * as unhealthy. Retries are attempted immediately.
     */
    retries?: number;
    /**
     * If suspended, no health checks are sent to the origin.
     */
    suspended?: boolean;
    /**
     * Parameters specific to TCP health check.
     */
    tcp_config?: HealthcheckEditParams.TcpConfig | null;
    /**
     * The timeout (in seconds) before marking the health check as failed.
     */
    timeout?: number;
    /**
     * The protocol to use for the health check. Currently supported protocols are
     * 'HTTP', 'HTTPS' and 'TCP'.
     */
    type?: string;
}
export declare namespace HealthcheckEditParams {
    /**
     * Parameters specific to an HTTP or HTTPS health check.
     */
    interface HTTPConfig {
        /**
         * Do not validate the certificate when the health check uses HTTPS.
         */
        allow_insecure?: boolean;
        /**
         * A case-insensitive sub-string to look for in the response body. If this string
         * is not found, the origin will be marked as unhealthy.
         */
        expected_body?: string;
        /**
         * The expected HTTP response codes (e.g. "200") or code ranges (e.g. "2xx" for all
         * codes starting with 2) of the health check.
         */
        expected_codes?: Array<string> | null;
        /**
         * Follow redirects if the origin returns a 3xx status code.
         */
        follow_redirects?: boolean;
        /**
         * The HTTP request headers to send in the health check. It is recommended you set
         * a Host header by default. The User-Agent header cannot be overridden.
         */
        header?: unknown | null;
        /**
         * The HTTP method to use for the health check.
         */
        method?: 'GET' | 'HEAD';
        /**
         * The endpoint path to health check against.
         */
        path?: string;
        /**
         * Port number to connect to for the health check. Defaults to 80 if type is HTTP
         * or 443 if type is HTTPS.
         */
        port?: number;
    }
    /**
     * Parameters specific to TCP health check.
     */
    interface TcpConfig {
        /**
         * The TCP connection method to use for the health check.
         */
        method?: 'connection_established';
        /**
         * Port number to connect to for the health check. Defaults to 80.
         */
        port?: number;
    }
}
export declare namespace Healthchecks {
    export import HealthchecksHealthchecks = HealthchecksAPI.HealthchecksHealthchecks;
    export import HealthcheckListResponse = HealthchecksAPI.HealthcheckListResponse;
    export import HealthcheckDeleteResponse = HealthchecksAPI.HealthcheckDeleteResponse;
    export import HealthcheckCreateParams = HealthchecksAPI.HealthcheckCreateParams;
    export import HealthcheckUpdateParams = HealthchecksAPI.HealthcheckUpdateParams;
    export import HealthcheckEditParams = HealthchecksAPI.HealthcheckEditParams;
    export import Previews = PreviewsAPI.Previews;
    export import PreviewDeleteResponse = PreviewsAPI.PreviewDeleteResponse;
    export import PreviewCreateParams = PreviewsAPI.PreviewCreateParams;
}
//# sourceMappingURL=healthchecks.d.ts.map