import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as KeysAPI from 'cloudflare/resources/images/v1/keys';
export declare class Keys extends APIResource {
    /**
     * Create a new signing key with specified name. Returns all keys available.
     */
    update(signingKeyName: unknown, params: KeyUpdateParams, options?: Core.RequestOptions): Core.APIPromise<ImagesImageKeys>;
    /**
     * Lists your signing keys. These can be found on your Cloudflare Images dashboard.
     */
    list(params: KeyListParams, options?: Core.RequestOptions): Core.APIPromise<ImagesImageKeys>;
    /**
     * Delete signing key with specified name. Returns all keys available. When last
     * key is removed, a new default signing key will be generated.
     */
    delete(signingKeyName: unknown, params: KeyDeleteParams, options?: Core.RequestOptions): Core.APIPromise<ImagesImageKeys>;
}
export interface ImagesImageKeys {
    keys?: Array<ImagesImageKeys.Key>;
}
export declare namespace ImagesImageKeys {
    interface Key {
        /**
         * Key name.
         */
        name?: string;
        /**
         * Key value.
         */
        value?: string;
    }
}
export interface KeyUpdateParams {
    /**
     * Account identifier tag.
     */
    account_id: string;
}
export interface KeyListParams {
    /**
     * Account identifier tag.
     */
    account_id: string;
}
export interface KeyDeleteParams {
    /**
     * Account identifier tag.
     */
    account_id: string;
}
export declare namespace Keys {
    export import ImagesImageKeys = KeysAPI.ImagesImageKeys;
    export import KeyUpdateParams = KeysAPI.KeyUpdateParams;
    export import KeyListParams = KeysAPI.KeyListParams;
    export import KeyDeleteParams = KeysAPI.KeyDeleteParams;
}
//# sourceMappingURL=keys.d.ts.map