import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as NamespacesAPI from 'cloudflare/resources/kv/namespaces/namespaces';
import * as BulkAPI from 'cloudflare/resources/kv/namespaces/bulk';
import * as KeysAPI from 'cloudflare/resources/kv/namespaces/keys';
import * as MetadataAPI from 'cloudflare/resources/kv/namespaces/metadata';
import * as ValuesAPI from 'cloudflare/resources/kv/namespaces/values';
import { V4PagePaginationArray, type V4PagePaginationArrayParams } from 'cloudflare/pagination';
export declare class Namespaces extends APIResource {
    bulk: BulkAPI.Bulk;
    keys: KeysAPI.Keys;
    metadata: MetadataAPI.Metadata;
    values: ValuesAPI.Values;
    /**
     * Creates a namespace under the given title. A `400` is returned if the account
     * already owns a namespace with this title. A namespace must be explicitly deleted
     * to be replaced.
     */
    create(params: NamespaceCreateParams, options?: Core.RequestOptions): Core.APIPromise<WorkersKVNamespace>;
    /**
     * Modifies a namespace's title.
     */
    update(namespaceId: string, params: NamespaceUpdateParams, options?: Core.RequestOptions): Core.APIPromise<NamespaceUpdateResponse>;
    /**
     * Returns the namespaces owned by an account.
     */
    list(params: NamespaceListParams, options?: Core.RequestOptions): Core.PagePromise<WorkersKVNamespacesV4PagePaginationArray, WorkersKVNamespace>;
    /**
     * Deletes the namespace corresponding to the given ID.
     */
    delete(namespaceId: string, params: NamespaceDeleteParams, options?: Core.RequestOptions): Core.APIPromise<NamespaceDeleteResponse>;
}
export declare class WorkersKVNamespacesV4PagePaginationArray extends V4PagePaginationArray<WorkersKVNamespace> {
}
export interface WorkersKVNamespace {
    /**
     * Namespace identifier tag.
     */
    id: string;
    /**
     * A human-readable string name for a Namespace.
     */
    title: string;
    /**
     * True if keys written on the URL will be URL-decoded before storing. For example,
     * if set to "true", a key written on the URL as "%3F" will be stored as "?".
     */
    supports_url_encoding?: boolean;
}
export type NamespaceUpdateResponse = unknown | string;
export type NamespaceDeleteResponse = unknown | string;
export interface NamespaceCreateParams {
    /**
     * Path param: Identifier
     */
    account_id: string;
    /**
     * Body param: A human-readable string name for a Namespace.
     */
    title: string;
}
export interface NamespaceUpdateParams {
    /**
     * Path param: Identifier
     */
    account_id: string;
    /**
     * Body param: A human-readable string name for a Namespace.
     */
    title: string;
}
export interface NamespaceListParams extends V4PagePaginationArrayParams {
    /**
     * Path param: Identifier
     */
    account_id: string;
    /**
     * Query param: Direction to order namespaces.
     */
    direction?: 'asc' | 'desc';
    /**
     * Query param: Field to order results by.
     */
    order?: 'id' | 'title';
}
export interface NamespaceDeleteParams {
    /**
     * Identifier
     */
    account_id: string;
}
export declare namespace Namespaces {
    export import WorkersKVNamespace = NamespacesAPI.WorkersKVNamespace;
    export import NamespaceUpdateResponse = NamespacesAPI.NamespaceUpdateResponse;
    export import NamespaceDeleteResponse = NamespacesAPI.NamespaceDeleteResponse;
    export import WorkersKVNamespacesV4PagePaginationArray = NamespacesAPI.WorkersKVNamespacesV4PagePaginationArray;
    export import NamespaceCreateParams = NamespacesAPI.NamespaceCreateParams;
    export import NamespaceUpdateParams = NamespacesAPI.NamespaceUpdateParams;
    export import NamespaceListParams = NamespacesAPI.NamespaceListParams;
    export import NamespaceDeleteParams = NamespacesAPI.NamespaceDeleteParams;
    export import Bulk = BulkAPI.Bulk;
    export import BulkUpdateResponse = BulkAPI.BulkUpdateResponse;
    export import BulkDeleteResponse = BulkAPI.BulkDeleteResponse;
    export import BulkUpdateParams = BulkAPI.BulkUpdateParams;
    export import BulkDeleteParams = BulkAPI.BulkDeleteParams;
    export import Keys = KeysAPI.Keys;
    export import WorkersKVKey = KeysAPI.WorkersKVKey;
    export import WorkersKVKeysCursorLimitPagination = KeysAPI.WorkersKVKeysCursorLimitPagination;
    export import KeyListParams = KeysAPI.KeyListParams;
    export import Metadata = MetadataAPI.Metadata;
    export import MetadataGetResponse = MetadataAPI.MetadataGetResponse;
    export import MetadataGetParams = MetadataAPI.MetadataGetParams;
    export import Values = ValuesAPI.Values;
    export import ValueUpdateResponse = ValuesAPI.ValueUpdateResponse;
    export import ValueDeleteResponse = ValuesAPI.ValueDeleteResponse;
    export import ValueGetResponse = ValuesAPI.ValueGetResponse;
    export import ValueUpdateParams = ValuesAPI.ValueUpdateParams;
    export import ValueDeleteParams = ValuesAPI.ValueDeleteParams;
    export import ValueGetParams = ValuesAPI.ValueGetParams;
}
//# sourceMappingURL=namespaces.d.ts.map