import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as HistoryAPI from 'cloudflare/resources/user/billing/history';
export declare class History extends APIResource {
    /**
     * Accesses your billing history object.
     */
    get(query?: HistoryGetParams, options?: Core.RequestOptions): Core.APIPromise<HistoryGetResponse | null>;
    get(options?: Core.RequestOptions): Core.APIPromise<HistoryGetResponse | null>;
}
export interface BillSubsAPIBillingHistory {
    /**
     * Billing item identifier tag.
     */
    id: string;
    /**
     * The billing item action.
     */
    action: string;
    /**
     * The amount associated with this billing item.
     */
    amount: number;
    /**
     * The monetary unit in which pricing information is displayed.
     */
    currency: string;
    /**
     * The billing item description.
     */
    description: string;
    /**
     * When the billing item was created.
     */
    occurred_at: string;
    /**
     * The billing item type.
     */
    type: string;
    zone: BillSubsAPIBillingHistory.Zone;
}
export declare namespace BillSubsAPIBillingHistory {
    interface Zone {
        name?: unknown;
    }
}
export type HistoryGetResponse = Array<BillSubsAPIBillingHistory>;
export interface HistoryGetParams {
    /**
     * Field to order billing history by.
     */
    order?: 'type' | 'occured_at' | 'action';
    /**
     * Page number of paginated results.
     */
    page?: number;
    /**
     * Number of items per page.
     */
    per_page?: number;
}
export declare namespace History {
    export import BillSubsAPIBillingHistory = HistoryAPI.BillSubsAPIBillingHistory;
    export import HistoryGetResponse = HistoryAPI.HistoryGetResponse;
    export import HistoryGetParams = HistoryAPI.HistoryGetParams;
}
//# sourceMappingURL=history.d.ts.map