import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as BookmarksAPI from 'cloudflare/resources/zero-trust/access/bookmarks';
export declare class Bookmarks extends APIResource {
    /**
     * Create a new Bookmark application.
     */
    create(identifier: unknown, uuid: string, options?: Core.RequestOptions): Core.APIPromise<AccessBookmarks>;
    /**
     * Updates a configured Bookmark application.
     */
    update(identifier: unknown, uuid: string, options?: Core.RequestOptions): Core.APIPromise<AccessBookmarks>;
    /**
     * Lists Bookmark applications.
     */
    list(identifier: unknown, options?: Core.RequestOptions): Core.APIPromise<BookmarkListResponse | null>;
    /**
     * Deletes a Bookmark application.
     */
    delete(identifier: unknown, uuid: string, options?: Core.RequestOptions): Core.APIPromise<BookmarkDeleteResponse>;
    /**
     * Fetches a single Bookmark application.
     */
    get(identifier: unknown, uuid: string, options?: Core.RequestOptions): Core.APIPromise<AccessBookmarks>;
}
export interface AccessBookmarks {
    /**
     * The unique identifier for the Bookmark application.
     */
    id?: unknown;
    /**
     * Displays the application in the App Launcher.
     */
    app_launcher_visible?: boolean;
    created_at?: string;
    /**
     * The domain of the Bookmark application.
     */
    domain?: string;
    /**
     * The image URL for the logo shown in the App Launcher dashboard.
     */
    logo_url?: string;
    /**
     * The name of the Bookmark application.
     */
    name?: string;
    updated_at?: string;
}
export type BookmarkListResponse = Array<AccessBookmarks>;
export interface BookmarkDeleteResponse {
    /**
     * UUID
     */
    id?: string;
}
export declare namespace Bookmarks {
    export import AccessBookmarks = BookmarksAPI.AccessBookmarks;
    export import BookmarkListResponse = BookmarksAPI.BookmarkListResponse;
    export import BookmarkDeleteResponse = BookmarksAPI.BookmarkDeleteResponse;
}
//# sourceMappingURL=bookmarks.d.ts.map