import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as ColosAPI from 'cloudflare/resources/zero-trust/dex/colos';
export declare class Colos extends APIResource {
    /**
     * List Cloudflare colos that account's devices were connected to during a time
     * period, sorted by usage starting from the most used colo. Colos without traffic
     * are also returned and sorted alphabetically.
     */
    list(params: ColoListParams, options?: Core.RequestOptions): Core.APIPromise<ColoListResponse | null>;
}
/**
 * array of colos.
 */
export type ColoListResponse = Array<unknown>;
export interface ColoListParams {
    /**
     * Path param: unique identifier linked to an account in the API request path.
     */
    account_id: string;
    /**
     * Query param: End time for connection period in RFC3339 (ISO 8601) format.
     */
    timeEnd: string;
    /**
     * Query param: Start time for connection period in RFC3339 (ISO 8601) format.
     */
    timeStart: string;
    /**
     * Query param: Type of usage that colos should be sorted by. If unspecified,
     * returns all Cloudflare colos sorted alphabetically.
     */
    sortBy?: 'fleet-status-usage' | 'application-tests-usage';
}
export declare namespace Colos {
    export import ColoListResponse = ColosAPI.ColoListResponse;
    export import ColoListParams = ColosAPI.ColoListParams;
}
//# sourceMappingURL=colos.d.ts.map