// File generated from our OpenAPI spec by Stainless.
import { APIResource } from 'cloudflare/resource';
import * as RoutesAPI from 'cloudflare/resources/zero-trust/networks/routes/routes';
import * as IPsAPI from 'cloudflare/resources/zero-trust/networks/routes/ips';
import * as NetworksAPI from 'cloudflare/resources/zero-trust/networks/routes/networks';
import { V4PagePaginationArray } from 'cloudflare/pagination';
export class Routes extends APIResource {
    constructor() {
        super(...arguments);
        this.ips = new IPsAPI.IPs(this._client);
        this.networks = new NetworksAPI.Networks(this._client);
    }
    /**
     * Routes a private network through a Cloudflare Tunnel.
     */
    create(params, options) {
        const { account_id, ...body } = params;
        return this._client.post(`/accounts/${account_id}/teamnet/routes`, { body, ...options })._thenUnwrap((obj) => obj.result);
    }
    /**
     * Lists and filters private network routes in an account.
     */
    list(params, options) {
        const { account_id, ...query } = params;
        return this._client.getAPIList(`/accounts/${account_id}/teamnet/routes`, TunnelTeamnetsV4PagePaginationArray, { query, ...options });
    }
    /**
     * Deletes a private network route from an account.
     */
    delete(routeId, params, options) {
        const { account_id } = params;
        return this._client.delete(`/accounts/${account_id}/teamnet/routes/${routeId}`, options)._thenUnwrap((obj) => obj.result);
    }
    /**
     * Updates an existing private network route in an account. The fields that are
     * meant to be updated should be provided in the body of the request.
     */
    edit(routeId, params, options) {
        const { account_id, ...body } = params;
        return this._client.patch(`/accounts/${account_id}/teamnet/routes/${routeId}`, {
            body,
            ...options,
        })._thenUnwrap((obj) => obj.result);
    }
}
export class TunnelTeamnetsV4PagePaginationArray extends V4PagePaginationArray {
}
(function (Routes) {
    Routes.TunnelTeamnetsV4PagePaginationArray = RoutesAPI.TunnelTeamnetsV4PagePaginationArray;
    Routes.IPs = IPsAPI.IPs;
    Routes.Networks = NetworksAPI.Networks;
})(Routes || (Routes = {}));
//# sourceMappingURL=routes.mjs.map