import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as BrowserCheckAPI from 'cloudflare/resources/zones/settings/browser-check';
export declare class BrowserCheck extends APIResource {
    /**
     * Browser Integrity Check is similar to Bad Behavior and looks for common HTTP
     * headers abused most commonly by spammers and denies access to your page. It will
     * also challenge visitors that do not have a user agent or a non standard user
     * agent (also commonly used by abuse bots, crawlers or visitors).
     * (https://support.cloudflare.com/hc/en-us/articles/200170086).
     */
    edit(params: BrowserCheckEditParams, options?: Core.RequestOptions): Core.APIPromise<ZonesBrowserCheck>;
    /**
     * Browser Integrity Check is similar to Bad Behavior and looks for common HTTP
     * headers abused most commonly by spammers and denies access to your page. It will
     * also challenge visitors that do not have a user agent or a non standard user
     * agent (also commonly used by abuse bots, crawlers or visitors).
     * (https://support.cloudflare.com/hc/en-us/articles/200170086).
     */
    get(params: BrowserCheckGetParams, options?: Core.RequestOptions): Core.APIPromise<ZonesBrowserCheck>;
}
/**
 * Browser Integrity Check is similar to Bad Behavior and looks for common HTTP
 * headers abused most commonly by spammers and denies access to your page. It will
 * also challenge visitors that do not have a user agent or a non standard user
 * agent (also commonly used by abuse bots, crawlers or visitors).
 * (https://support.cloudflare.com/hc/en-us/articles/200170086).
 */
export interface ZonesBrowserCheck {
    /**
     * ID of the zone setting.
     */
    id: 'browser_check';
    /**
     * Current value of the zone setting.
     */
    value: 'on' | 'off';
    /**
     * Whether or not this setting can be modified for this zone (based on your
     * Cloudflare plan level).
     */
    editable?: true | false;
    /**
     * last time this setting was modified.
     */
    modified_on?: string | null;
}
export interface BrowserCheckEditParams {
    /**
     * Path param: Identifier
     */
    zone_id: string;
    /**
     * Body param: Value of the zone setting.
     */
    value: 'on' | 'off';
}
export interface BrowserCheckGetParams {
    /**
     * Identifier
     */
    zone_id: string;
}
export declare namespace BrowserCheck {
    export import ZonesBrowserCheck = BrowserCheckAPI.ZonesBrowserCheck;
    export import BrowserCheckEditParams = BrowserCheckAPI.BrowserCheckEditParams;
    export import BrowserCheckGetParams = BrowserCheckAPI.BrowserCheckGetParams;
}
//# sourceMappingURL=browser-check.d.ts.map