import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as HTTP2API from 'cloudflare/resources/zones/settings/http2';
export declare class HTTP2 extends APIResource {
    /**
     * Value of the HTTP2 setting.
     */
    edit(params: HTTP2EditParams, options?: Core.RequestOptions): Core.APIPromise<ZonesHTTP2>;
    /**
     * Value of the HTTP2 setting.
     */
    get(params: HTTP2GetParams, options?: Core.RequestOptions): Core.APIPromise<ZonesHTTP2>;
}
/**
 * HTTP2 enabled for this zone.
 */
export interface ZonesHTTP2 {
    /**
     * ID of the zone setting.
     */
    id: 'http2';
    /**
     * Current value of the zone setting.
     */
    value: 'on' | 'off';
    /**
     * Whether or not this setting can be modified for this zone (based on your
     * Cloudflare plan level).
     */
    editable?: true | false;
    /**
     * last time this setting was modified.
     */
    modified_on?: string | null;
}
export interface HTTP2EditParams {
    /**
     * Path param: Identifier
     */
    zone_id: string;
    /**
     * Body param: Value of the HTTP2 setting.
     */
    value: 'on' | 'off';
}
export interface HTTP2GetParams {
    /**
     * Identifier
     */
    zone_id: string;
}
export declare namespace HTTP2 {
    export import ZonesHTTP2 = HTTP2API.ZonesHTTP2;
    export import HTTP2EditParams = HTTP2API.HTTP2EditParams;
    export import HTTP2GetParams = HTTP2API.HTTP2GetParams;
}
//# sourceMappingURL=http2.d.ts.map