import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as TLSClientAuthAPI from 'cloudflare/resources/zones/settings/tls-client-auth';
export declare class TLSClientAuth extends APIResource {
    /**
     * TLS Client Auth requires Cloudflare to connect to your origin server using a
     * client certificate (Enterprise Only).
     */
    edit(params: TLSClientAuthEditParams, options?: Core.RequestOptions): Core.APIPromise<ZonesTLSClientAuth>;
    /**
     * TLS Client Auth requires Cloudflare to connect to your origin server using a
     * client certificate (Enterprise Only).
     */
    get(params: TLSClientAuthGetParams, options?: Core.RequestOptions): Core.APIPromise<ZonesTLSClientAuth>;
}
/**
 * TLS Client Auth requires Cloudflare to connect to your origin server using a
 * client certificate (Enterprise Only).
 */
export interface ZonesTLSClientAuth {
    /**
     * ID of the zone setting.
     */
    id: 'tls_client_auth';
    /**
     * Current value of the zone setting.
     */
    value: 'on' | 'off';
    /**
     * Whether or not this setting can be modified for this zone (based on your
     * Cloudflare plan level).
     */
    editable?: true | false;
    /**
     * last time this setting was modified.
     */
    modified_on?: string | null;
}
export interface TLSClientAuthEditParams {
    /**
     * Path param: Identifier
     */
    zone_id: string;
    /**
     * Body param: value of the zone setting.
     */
    value: 'on' | 'off';
}
export interface TLSClientAuthGetParams {
    /**
     * Identifier
     */
    zone_id: string;
}
export declare namespace TLSClientAuth {
    export import ZonesTLSClientAuth = TLSClientAuthAPI.ZonesTLSClientAuth;
    export import TLSClientAuthEditParams = TLSClientAuthAPI.TLSClientAuthEditParams;
    export import TLSClientAuthGetParams = TLSClientAuthAPI.TLSClientAuthGetParams;
}
//# sourceMappingURL=tls-client-auth.d.ts.map